
# Slot: biomarker for


holds between a measurable molecular entity and a disease or phenotypic feature, where the entity is used as an indicator of the presence or state of the disease or feature.

URI: [biolink:biomarker_for](https://w3id.org/biolink/vocab/biomarker_for)


## Domain and Range

[MolecularEntity](MolecularEntity.md) &#8594;  <sub>0..\*</sub> [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)

## Parents

 *  is_a: [correlated with](correlated_with.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | NCIT:R39 |
| **Narrow Mappings:** | | NCIT:R47 |
|  | | NCIT:genetic_biomarker_related_to |
|  | | NCIT:is_molecular_abnormality_of_disease |
|  | | ORPHA:465410 |
|  | | SEMMEDDB:diagnoses |
| **Broad Mappings:** | | RO:0002607 |

